# coding: utf-8

# Copyright 2011 Robert Siemer <Robert.Siemer-anki@backsla.sh>

# This file is part of “Panki Chinese”.

# “Panki Chinese” is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# “Panki Chinese” is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with “Panki Chinese”.  If not, see <http://www.gnu.org/licenses/>.



# This plugin brings the externalized templates, scripts and styles for
# the “Panki Chinese” deck back into the program.

# See  http://backsla.sh/anki/panki  and/or the main plugin file for more
# information.

import os, re, codecs, anki.hooks

# __file__ is the absolute filename of this module
#modulepath = os.path.dirname(__file__) + '/'

def f(card, name, mode='r'):
    name = os.path.join(card.cardModel.model.deck.mediaDir(create=None), name)
    return codecs.open(name, mode, encoding='utf-8')

def preRenderHook(old, card, *p, **kw):
    cardModel = card.cardModel.name
    cardModel = cardModel.replace('*', '_')
    if cardModel[-1] in '234':
        cardModel, ordinal = cardModel[:-1], cardModel[-1]
    else:
        ordinal = ''
    tFile = f(card, 'cardmodel.' + cardModel + '.html').read()
    template = tFile.split(u'-----\n')
    if kw['qa'] == 'question':
        common = f(card, 'common.html').read()
        if not cardModel.endswith('sentence'):
            common = common.replace(
                ' <span class=knownpercent>{{{Sentence1 Percentage}}}%</span>', '')
        template = common + template[0] + f(card, 'commonimg.html').read()
    else:
        template = template[1]
    if ordinal:
        template = template.replace('Sentence1', 'Sentence' + ordinal)
        template += '<style>html {background: #fff;}</style>'
    return template

def drawHook(old, card, *p, **kw):
    return old + f(card, 'script.html').read()

def pankiCheck(func):
    def checkfirst(old, card, *p, **kw):
        if card.cardModel.model.name == u'Chinese characters, compounds and sentences':
            return func(old, card, *p, **kw)
        else:
            return old
    return checkfirst

anki.hooks.addHook('drawQuestion', pankiCheck(drawHook))
anki.hooks.addHook('preRenderFormatQA', pankiCheck(preRenderHook))
